diff --git a/CRM/Yoteup/Form/Report/IndividualCounselor.mgd.php b/CRM/Nrm/Form/Report/IndividualCounselor.mgd.php
similarity index 81%
rename from CRM/Yoteup/Form/Report/IndividualCounselor.mgd.php
rename to CRM/Nrm/Form/Report/IndividualCounselor.mgd.php
index 292a3dca633a7a191b30efb4d1aa3a0784e63d12..68a0b5f02234e1c0df47e85ae2c731004c931efd 100644
--- a/CRM/Yoteup/Form/Report/IndividualCounselor.mgd.php
+++ b/CRM/Nrm/Form/Report/IndividualCounselor.mgd.php
@@ -6,14 +6,14 @@
 return array (
   0 => 
   array (
-    'name' => 'CRM_Yoteup_Form_Report_IndividualCounselor',
+    'name' => 'CRM_Nrm_Form_Report_IndividualCounselor',
     'entity' => 'ReportTemplate',
     'params' => 
     array (
       'version' => 3,
       'label' => 'Individual Counselor',
-      'description' => 'Individual Counselor (biz.jmaconsulting.yoteup)',
-      'class_name' => 'CRM_Yoteup_Form_Report_IndividualCounselor',
+      'description' => 'Individual Counselor (biz.jmaconsulting.nrm)',
+      'class_name' => 'CRM_Nrm_Form_Report_IndividualCounselor',
       'report_url' => 'yoteup/individualcounselor',
       'component' => '',
     ),
diff --git a/CRM/Yoteup/Form/Report/IndividualCounselor.php b/CRM/Nrm/Form/Report/IndividualCounselor.php
similarity index 99%
rename from CRM/Yoteup/Form/Report/IndividualCounselor.php
rename to CRM/Nrm/Form/Report/IndividualCounselor.php
index 3da78d441a061a38e45a25f405466e1893abd1a8..02de74fbb983fe6d68714ae3508d28503f98f12a 100644
--- a/CRM/Yoteup/Form/Report/IndividualCounselor.php
+++ b/CRM/Nrm/Form/Report/IndividualCounselor.php
@@ -1,8 +1,8 @@
 <?php
 
-require_once 'yoteup_constants.php';
+require_once 'nrm_constants.php';
 
-class CRM_Yoteup_Form_Report_IndividualCounselor extends CRM_Report_Form {
+class CRM_Nrm_Form_Report_IndividualCounselor extends CRM_Report_Form {
 
   protected $_addressField = FALSE;
 
diff --git a/CRM/Yoteup/Form/Report/ManagementSummary.mgd.php b/CRM/Nrm/Form/Report/ManagementSummary.mgd.php
similarity index 73%
rename from CRM/Yoteup/Form/Report/ManagementSummary.mgd.php
rename to CRM/Nrm/Form/Report/ManagementSummary.mgd.php
index 84fc193d1cc2d89c05ee0eb2f23e8990abc49efb..9e374c6fcc622b6db27c2eab560b6edc09b2dc08 100644
--- a/CRM/Yoteup/Form/Report/ManagementSummary.mgd.php
+++ b/CRM/Nrm/Form/Report/ManagementSummary.mgd.php
@@ -6,14 +6,14 @@
 return array (
   0 => 
   array (
-    'name' => 'CRM_Yoteup_Form_Report_ManagementSummary',
+    'name' => 'CRM_Nrm_Form_Report_ManagementSummary',
     'entity' => 'ReportTemplate',
     'params' => 
     array (
       'version' => 3,
       'label' => 'Management Summary',
-      'description' => 'Management Summary (biz.jmaconsulting.yoteup)',
-      'class_name' => 'CRM_Yoteup_Form_Report_ManagementSummary',
+      'description' => 'Management Summary (biz.jmaconsulting.nrm)',
+      'class_name' => 'CRM_Nrm_Form_Report_ManagementSummary',
       'report_url' => 'yoteup/managementsummary',
       'component' => '',
     ),
diff --git a/CRM/Yoteup/Form/Report/ManagementSummary.php b/CRM/Nrm/Form/Report/ManagementSummary.php
similarity index 99%
rename from CRM/Yoteup/Form/Report/ManagementSummary.php
rename to CRM/Nrm/Form/Report/ManagementSummary.php
index cd804e8fea73a67d3c2c615ddf8b9f023fb7e6fa..ac60d9eb974fa4ae6282289055d252d49a5cd5d9 100644
--- a/CRM/Yoteup/Form/Report/ManagementSummary.php
+++ b/CRM/Nrm/Form/Report/ManagementSummary.php
@@ -1,8 +1,8 @@
 <?php
 
-require_once 'yoteup_constants.php';
+require_once 'nrm_constants.php';
 
-class CRM_Yoteup_Form_Report_ManagementSummary extends CRM_Report_Form {
+class CRM_Nrm_Form_Report_ManagementSummary extends CRM_Report_Form {
 
   protected $_summary = NULL;
 
diff --git a/CRM/Yoteup/Form/Report/PersonalVisit.mgd.php b/CRM/Nrm/Form/Report/PersonalVisit.mgd.php
similarity index 74%
rename from CRM/Yoteup/Form/Report/PersonalVisit.mgd.php
rename to CRM/Nrm/Form/Report/PersonalVisit.mgd.php
index 84964b774801003f434c24bbd3d7290c7e89a9b7..f21c63f4b4b3fb966ad519270cf2438ce06fa04d 100644
--- a/CRM/Yoteup/Form/Report/PersonalVisit.mgd.php
+++ b/CRM/Nrm/Form/Report/PersonalVisit.mgd.php
@@ -6,14 +6,14 @@
 return array (
   0 => 
   array (
-    'name' => 'CRM_Yoteup_Form_Report_PersonalVisit',
+    'name' => 'CRM_Nrm_Form_Report_PersonalVisit',
     'entity' => 'ReportTemplate',
     'params' => 
     array (
       'version' => 3,
       'label' => 'Personal Visit Day',
-      'description' => 'Personal Visit Day (biz.jmaconsulting.yoteup)',
-      'class_name' => 'CRM_Yoteup_Form_Report_PersonalVisit',
+      'description' => 'Personal Visit Day (biz.jmaconsulting.nrm)',
+      'class_name' => 'CRM_Nrm_Form_Report_PersonalVisit',
       'report_url' => 'chowan/personalvisit',
       'component' => '',
     ),
diff --git a/CRM/Yoteup/Form/Report/PersonalVisit.php b/CRM/Nrm/Form/Report/PersonalVisit.php
similarity index 94%
rename from CRM/Yoteup/Form/Report/PersonalVisit.php
rename to CRM/Nrm/Form/Report/PersonalVisit.php
index b549bea8c67c5809604c5f6af1f742d29b039b3d..d3603cb241d98fa0cf6106d9c5e2a361b571dd4d 100644
--- a/CRM/Yoteup/Form/Report/PersonalVisit.php
+++ b/CRM/Nrm/Form/Report/PersonalVisit.php
@@ -1,6 +1,6 @@
 <?php
 
-class CRM_Yoteup_Form_Report_PersonalVisit extends CRM_Report_Form {
+class CRM_Nrm_Form_Report_PersonalVisit extends CRM_Report_Form {
 
   protected $_summary = NULL;
 
@@ -148,7 +148,7 @@ class CRM_Yoteup_Form_Report_PersonalVisit extends CRM_Report_Form {
         'title' => 'Comments/Requests',
       ),
     );
-    CRM_Yoteup_BAO_Yoteup::reportSelectClause($this, $columns);
+    CRM_Nrm_BAO_Nrm::reportSelectClause($this, $columns);
   }
 
   function from() {
@@ -157,11 +157,11 @@ class CRM_Yoteup_Form_Report_PersonalVisit extends CRM_Report_Form {
       171 => 'academic',
       158 => 'extra',
     );
-    CRM_Yoteup_BAO_Yoteup::reportFromClause($this->_from, FALSE, array(), $custom);
+    CRM_Nrm_BAO_Nrm::reportFromClause($this->_from, FALSE, array(), $custom);
   }
 
   function where() {
-    CRM_Yoteup_BAO_Yoteup::reportWhereClause($this->_where, 89);
+    CRM_Nrm_BAO_Nrm::reportWhereClause($this->_where, 89);
   }
 
   function groupBy() {
diff --git a/CRM/Yoteup/Form/Report/RequestedInfo.mgd.php b/CRM/Nrm/Form/Report/RequestedInfo.mgd.php
similarity index 82%
rename from CRM/Yoteup/Form/Report/RequestedInfo.mgd.php
rename to CRM/Nrm/Form/Report/RequestedInfo.mgd.php
index fdeaa6d088fff20f40682a4535c9b65358ab5433..1577cb32892ff621cdc3b6769cc8ca57e0e81402 100644
--- a/CRM/Yoteup/Form/Report/RequestedInfo.mgd.php
+++ b/CRM/Nrm/Form/Report/RequestedInfo.mgd.php
@@ -6,14 +6,14 @@
 return array (
   0 => 
   array (
-    'name' => 'CRM_Yoteup_Form_Report_RequestedInfo',
+    'name' => 'CRM_Nrm_Form_Report_RequestedInfo',
     'entity' => 'ReportTemplate',
     'params' => 
     array (
       'version' => 3,
       'label' => 'Requested Information',
-      'description' => 'Requested Information (biz.jmaconsulting.yoteup)',
-      'class_name' => 'CRM_Yoteup_Form_Report_RequestedInfo',
+      'description' => 'Requested Information (biz.jmaconsulting.nrm)',
+      'class_name' => 'CRM_Nrm_Form_Report_RequestedInfo',
       'report_url' => 'yoteup/requestedinfo',
       'component' => '',
     ),
diff --git a/CRM/Yoteup/Form/Report/RequestedInfo.php b/CRM/Nrm/Form/Report/RequestedInfo.php
similarity index 92%
rename from CRM/Yoteup/Form/Report/RequestedInfo.php
rename to CRM/Nrm/Form/Report/RequestedInfo.php
index 4f7de30a868cd1d596bd9bdc3aa5d1ddb2c4d87b..f732927ae66e0b1f24d989f1ca97cc691628b2c4 100644
--- a/CRM/Yoteup/Form/Report/RequestedInfo.php
+++ b/CRM/Nrm/Form/Report/RequestedInfo.php
@@ -1,6 +1,6 @@
 <?php
 
-class CRM_Yoteup_Form_Report_RequestedInfo extends CRM_Report_Form {
+class CRM_Nrm_Form_Report_RequestedInfo extends CRM_Report_Form {
 
   protected $_summary = NULL;
 
@@ -105,7 +105,7 @@ class CRM_Yoteup_Form_Report_RequestedInfo extends CRM_Report_Form {
       ),
     );
 
-    CRM_Yoteup_BAO_Yoteup::reportSelectClause($this, $columns);
+    CRM_Nrm_BAO_Nrm::reportSelectClause($this, $columns);
   }
 
   function from() { 
@@ -114,11 +114,11 @@ class CRM_Yoteup_Form_Report_RequestedInfo extends CRM_Report_Form {
       171 => 'academic',
       158 => 'extra',
     );
-    CRM_Yoteup_BAO_Yoteup::reportFromClause($this->_from, FALSE, array(), $custom);
+    CRM_Nrm_BAO_Nrm::reportFromClause($this->_from, FALSE, array(), $custom);
   }
 
   function where() {
-    CRM_Yoteup_BAO_Yoteup::reportWhereClause($this->_where, 72);
+    CRM_Nrm_BAO_Nrm::reportWhereClause($this->_where, 72);
   }
 
   function groupBy() {
diff --git a/CRM/Yoteup/Form/Report/SurveyDaily.mgd.php b/CRM/Nrm/Form/Report/SurveyDaily.mgd.php
similarity index 74%
rename from CRM/Yoteup/Form/Report/SurveyDaily.mgd.php
rename to CRM/Nrm/Form/Report/SurveyDaily.mgd.php
index 2416b2afa51787fa19d44e54d52ce208e8b196c1..ca0b736cc77a5e8f833a10c0cc643e8940f3ae20 100644
--- a/CRM/Yoteup/Form/Report/SurveyDaily.mgd.php
+++ b/CRM/Nrm/Form/Report/SurveyDaily.mgd.php
@@ -6,14 +6,14 @@
 return array (
   0 => 
   array (
-    'name' => 'CRM_Yoteup_Form_Report_SurveyDaily',
+    'name' => 'CRM_Nrm_Form_Report_SurveyDaily',
     'entity' => 'ReportTemplate',
     'params' => 
     array (
       'version' => 3,
       'label' => 'Survey Daily Report',
-      'description' => 'Survey Daily Report (biz.jmaconsulting.yoteup)',
-      'class_name' => 'CRM_Yoteup_Form_Report_SurveyDaily',
+      'description' => 'Survey Daily Report (biz.jmaconsulting.nrm)',
+      'class_name' => 'CRM_Nrm_Form_Report_SurveyDaily',
       'report_url' => 'yoteup/surveydaily',
       'component' => '',
     ),
diff --git a/CRM/Yoteup/Form/Report/SurveyDaily.php b/CRM/Nrm/Form/Report/SurveyDaily.php
similarity index 98%
rename from CRM/Yoteup/Form/Report/SurveyDaily.php
rename to CRM/Nrm/Form/Report/SurveyDaily.php
index 1b833179abd56940af44693e9f299e86f9966036..9d49097a2bc513804bd0edea2cd4026ca58c0232 100644
--- a/CRM/Yoteup/Form/Report/SurveyDaily.php
+++ b/CRM/Nrm/Form/Report/SurveyDaily.php
@@ -1,6 +1,6 @@
 <?php
 
-class CRM_Yoteup_Form_Report_SurveyDaily extends CRM_Report_Form {
+class CRM_Nrm_Form_Report_SurveyDaily extends CRM_Report_Form {
 
   protected $_summary = NULL;
 
@@ -114,7 +114,7 @@ class CRM_Yoteup_Form_Report_SurveyDaily extends CRM_Report_Form {
         'ignore_group_concat' => TRUE,
       ),
     );
-    CRM_Yoteup_BAO_Yoteup::reportSelectClause($this, $columns, FALSE, FALSE);
+    CRM_Nrm_BAO_Nrm::reportSelectClause($this, $columns, FALSE, FALSE);
   }
 
   function from() { 
diff --git a/CRM/Yoteup/Form/Report/UpdateInfo.mgd.php b/CRM/Nrm/Form/Report/UpdateInfo.mgd.php
similarity index 74%
rename from CRM/Yoteup/Form/Report/UpdateInfo.mgd.php
rename to CRM/Nrm/Form/Report/UpdateInfo.mgd.php
index 74c246c4ca7d50e1633803564173a74dfe24fd90..cde654b2cba494756b4d876d066a6c8a62f0bf00 100644
--- a/CRM/Yoteup/Form/Report/UpdateInfo.mgd.php
+++ b/CRM/Nrm/Form/Report/UpdateInfo.mgd.php
@@ -6,14 +6,14 @@
 return array (
   0 => 
   array (
-    'name' => 'CRM_Yoteup_Form_Report_UpdateInfo',
+    'name' => 'CRM_Nrm_Form_Report_UpdateInfo',
     'entity' => 'ReportTemplate',
     'params' => 
     array (
       'version' => 3,
       'label' => 'Update Information',
-      'description' => 'Update Information (biz.jmaconsulting.yoteup)',
-      'class_name' => 'CRM_Yoteup_Form_Report_UpdateInfo',
+      'description' => 'Update Information (biz.jmaconsulting.nrm)',
+      'class_name' => 'CRM_Nrm_Form_Report_UpdateInfo',
       'report_url' => 'yoteup/updateinfo',
       'component' => '',
     ),
diff --git a/CRM/Yoteup/Form/Report/UpdateInfo.php b/CRM/Nrm/Form/Report/UpdateInfo.php
similarity index 91%
rename from CRM/Yoteup/Form/Report/UpdateInfo.php
rename to CRM/Nrm/Form/Report/UpdateInfo.php
index 313e58b3689c12c0752e88110f72f9209d533ae2..5bd817caaf60a8d87eba868ddb4e82fbefb97547 100644
--- a/CRM/Yoteup/Form/Report/UpdateInfo.php
+++ b/CRM/Nrm/Form/Report/UpdateInfo.php
@@ -1,6 +1,6 @@
 <?php
 
-class CRM_Yoteup_Form_Report_UpdateInfo extends CRM_Report_Form {
+class CRM_Nrm_Form_Report_UpdateInfo extends CRM_Report_Form {
 
   protected $_summary = NULL;
 
@@ -101,7 +101,7 @@ class CRM_Yoteup_Form_Report_UpdateInfo extends CRM_Report_Form {
         'columnName' => 'pt1.label',
       ),
     );
-    CRM_Yoteup_BAO_Yoteup::reportSelectClause($this, $columns);
+    CRM_Nrm_BAO_Nrm::reportSelectClause($this, $columns);
   }
 
   function from() { 
@@ -109,11 +109,11 @@ class CRM_Yoteup_Form_Report_UpdateInfo extends CRM_Report_Form {
       6 => 'prefix',
       7 => 'suffix',
      );
-    CRM_Yoteup_BAO_Yoteup::reportFromClause($this->_from, FALSE, array(), $custom);
+    CRM_Nrm_BAO_Nrm::reportFromClause($this->_from, FALSE, array(), $custom);
   }
 
   function where() {
-    CRM_Yoteup_BAO_Yoteup::reportWhereClause($this->_where, 67);
+    CRM_Nrm_BAO_Nrm::reportWhereClause($this->_where, 67);
   }
 
   function groupBy() {
diff --git a/CRM/Yoteup/Form/Report/VipApplication.mgd.php b/CRM/Nrm/Form/Report/VipApplication.mgd.php
similarity index 74%
rename from CRM/Yoteup/Form/Report/VipApplication.mgd.php
rename to CRM/Nrm/Form/Report/VipApplication.mgd.php
index 60c22c63a80e58c3566bda7cb52bd2869b2cf86e..55680e04be1ac845922fa3a4e2af44888583e810 100644
--- a/CRM/Yoteup/Form/Report/VipApplication.mgd.php
+++ b/CRM/Nrm/Form/Report/VipApplication.mgd.php
@@ -6,14 +6,14 @@
 return array (
   0 => 
   array (
-    'name' => 'CRM_Yoteup_Form_Report_VipApplication',
+    'name' => 'CRM_Nrm_Form_Report_VipApplication',
     'entity' => 'ReportTemplate',
     'params' => 
     array (
       'version' => 3,
       'label' => 'VIP Application',
-      'description' => 'VIP Application (biz.jmaconsulting.yoteup)',
-      'class_name' => 'CRM_Yoteup_Form_Report_VipApplication',
+      'description' => 'VIP Application (biz.jmaconsulting.nrm)',
+      'class_name' => 'CRM_Nrm_Form_Report_VipApplication',
       'report_url' => 'yoteup/vipapplication',
       'component' => '',
     ),
diff --git a/CRM/Yoteup/Form/Report/VipApplication.php b/CRM/Nrm/Form/Report/VipApplication.php
similarity index 97%
rename from CRM/Yoteup/Form/Report/VipApplication.php
rename to CRM/Nrm/Form/Report/VipApplication.php
index e8128523e28ac5d358f8d9fcfaf0c28ec6ab45ca..dd8d8738af65be4dce9d234300e21f74a6e5953a 100644
--- a/CRM/Yoteup/Form/Report/VipApplication.php
+++ b/CRM/Nrm/Form/Report/VipApplication.php
@@ -1,6 +1,6 @@
 <?php
 
-class CRM_Yoteup_Form_Report_VipApplication extends CRM_Report_Form {
+class CRM_Nrm_Form_Report_VipApplication extends CRM_Report_Form {
 
   protected $_summary = NULL;
 
@@ -392,7 +392,7 @@ class CRM_Yoteup_Form_Report_VipApplication extends CRM_Report_Form {
       ),
     );
 
-    CRM_Yoteup_BAO_Yoteup::reportSelectClause($this, $columns);
+    CRM_Nrm_BAO_Nrm::reportSelectClause($this, $columns);
   }
 
   function from() { 
@@ -406,11 +406,11 @@ class CRM_Yoteup_Form_Report_VipApplication extends CRM_Report_Form {
       171 => 'major',
       208 => 'visa',
     );
-    CRM_Yoteup_BAO_Yoteup::reportFromClause($this->_from, FALSE, array(), $custom);
+    CRM_Nrm_BAO_Nrm::reportFromClause($this->_from, FALSE, array(), $custom);
   }
 
   function where() {
-    CRM_Yoteup_BAO_Yoteup::reportWhereClause($this->_where, 70);
+    CRM_Nrm_BAO_Nrm::reportWhereClause($this->_where, 70);
   }
 
   function groupBy() {
diff --git a/LICENSE.txt b/LICENSE.txt
index 216e5259c9fdbe468e10f6d95ed77490bfbde4e0..ba2fe9fbe486ad4a9c6508be30c3245d2a437d76 100644
--- a/LICENSE.txt
+++ b/LICENSE.txt
@@ -1,4 +1,4 @@
-Package: biz.jmaconsulting.yoteup
+Package: biz.jmaconsulting.nrm
 Copyright (C) 2015, joe.murray@jmaconsulting.biz <edsel.lopez@jmaconsulting.biz>
 Licensed under the GNU Affero Public License 3.0 (below).
 
diff --git a/README.md b/README.md
index 853f6d0886cbd8986aee7f5bd5f2886e85cea5bd..0d4f4eebb7a4e5f38e6aff7da93dfea04f1b3331 100644
--- a/README.md
+++ b/README.md
@@ -1 +1 @@
-# biz.jmaconsulting.yoteup
+# biz.jmaconsulting.nrm
diff --git a/api/v3/Yoteup/ProcessCounselor.mgd.php b/api/v3/Nrm/ProcessCounselor.mgd.php
similarity index 88%
rename from api/v3/Yoteup/ProcessCounselor.mgd.php
rename to api/v3/Nrm/ProcessCounselor.mgd.php
index 089bb595f01dd9ca6f047ed3fc5dc27db13f3211..4ea2a92a815dd3fe71f58b9f941a4c063ce101e9 100644
--- a/api/v3/Yoteup/ProcessCounselor.mgd.php
+++ b/api/v3/Nrm/ProcessCounselor.mgd.php
@@ -6,7 +6,7 @@
 return array (
   0 => 
   array (
-    'name' => 'Cron:YoteUp.ProcessCounselor',
+    'name' => 'Cron:Nrm.ProcessCounselor',
     'entity' => 'Job',
     'params' => 
     array (
@@ -14,7 +14,7 @@ return array (
       'name' => 'Process Counselors',
       'description' => 'Send mail report to counselors',
       'run_frequency' => 'Daily',
-      'api_entity' => 'Yoteup',
+      'api_entity' => 'Nrm',
       'api_action' => 'Processcounselor',
       'parameters' => '',
     ),
diff --git a/api/v3/Yoteup/Processcounselor.php b/api/v3/Nrm/Processcounselor.php
similarity index 98%
rename from api/v3/Yoteup/Processcounselor.php
rename to api/v3/Nrm/Processcounselor.php
index 30a92cb0dde43db3ea4db1d2dd83c5614f9cc855..8f53c6a2ea28c676e89d15b9438679b2c92020f2 100644
--- a/api/v3/Yoteup/Processcounselor.php
+++ b/api/v3/Nrm/Processcounselor.php
@@ -9,7 +9,7 @@ define('TERRITORY_COUNSELOR', 446);
  * @see civicrm_api3_create_error
  * @throws API_Exception
  */
-function civicrm_api3_yoteup_processcounselor($params) {
+function civicrm_api3_nrm_processcounselor($params) {
   // Get list of counselors
   $counsellorCount = civicrm_api3('Contact', 'getCount', array('contact_sub_type' => 'Counselors'));
   $counselorParams = array(
diff --git a/info.xml b/info.xml
index e5c2bd3c9329969d477e16372d7658261e4ac4de..2e1716c179ca869596e962bbe683d88737478b87 100644
--- a/info.xml
+++ b/info.xml
@@ -1,17 +1,17 @@
 <?xml version="1.0"?>
-<extension key="biz.jmaconsulting.yoteup" type="module">
-  <file>yoteup</file>
-  <name>Yote UP Customization</name>
-  <description>Holds customization for yoteup2016.com</description>
+<extension key="biz.jmaconsulting.nrm" type="module">
+  <file>nrm</file>
+  <name>NRM Customization</name>
+  <description>Holds customization for NRM</description>
   <license>AGPL-3.0</license>
   <maintainer>
     <author>Joe Murray</author>
     <email>joe.murray@jmaconsulting.biz</email>
   </maintainer>
   <urls>
-    <url desc="Main Extension Page">https://github.com/JMAConsulting/biz.jmaconsulting.yoteup</url>
-    <url desc="Documentation">https://github.com/JMAConsulting/biz.jmaconsulting.yoteup/blob/master/README.md</url>
-    <url desc="Support">https://github.com/JMAConsulting/biz.jmaconsulting.yoteup/issues</url>
+    <url desc="Main Extension Page">https://github.com/JMAConsulting/biz.jmaconsulting.nrm</url>
+    <url desc="Documentation">https://github.com/JMAConsulting/biz.jmaconsulting.nrm/blob/master/README.md</url>
+    <url desc="Support">https://github.com/JMAConsulting/biz.jmaconsulting.nrm/issues</url>
     <url desc="Licensing">http://www.gnu.org/licenses/agpl-3.0.html</url>
   </urls>
   <releaseDate>2015-08-31</releaseDate>
@@ -22,6 +22,6 @@
   </compatibility>
   <comments>This is a new, undeveloped module</comments>
   <civix>
-    <namespace>CRM/Yoteup</namespace>
+    <namespace>CRM/Nrm</namespace>
   </civix>
 </extension>
diff --git a/yoteup.civix.php b/nrm.civix.php
similarity index 78%
rename from yoteup.civix.php
rename to nrm.civix.php
index e9bfd57bbaf1ce0488f9e1b933170a8f0b55cb10..4dc3a76dfd4b5b8059a6088a1c8c2383ecbb4c80 100644
--- a/yoteup.civix.php
+++ b/nrm.civix.php
@@ -7,7 +7,7 @@
  *
  * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_config
  */
-function _yoteup_civix_civicrm_config(&$config = NULL) {
+function _nrm_civix_civicrm_config(&$config = NULL) {
   static $configured = FALSE;
   if ($configured) return;
   $configured = TRUE;
@@ -33,8 +33,8 @@ function _yoteup_civix_civicrm_config(&$config = NULL) {
  * @param $files array(string)
  * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_xmlMenu
  */
-function _yoteup_civix_civicrm_xmlMenu(&$files) {
-  foreach (_yoteup_civix_glob(__DIR__ . '/xml/Menu/*.xml') as $file) {
+function _nrm_civix_civicrm_xmlMenu(&$files) {
+  foreach (_nrm_civix_glob(__DIR__ . '/xml/Menu/*.xml') as $file) {
     $files[] = $file;
   }
 }
@@ -44,9 +44,9 @@ function _yoteup_civix_civicrm_xmlMenu(&$files) {
  *
  * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_install
  */
-function _yoteup_civix_civicrm_install() {
-  _yoteup_civix_civicrm_config();
-  if ($upgrader = _yoteup_civix_upgrader()) {
+function _nrm_civix_civicrm_install() {
+  _nrm_civix_civicrm_config();
+  if ($upgrader = _nrm_civix_upgrader()) {
     $upgrader->onInstall();
   }
 }
@@ -56,9 +56,9 @@ function _yoteup_civix_civicrm_install() {
  *
  * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_uninstall
  */
-function _yoteup_civix_civicrm_uninstall() {
-  _yoteup_civix_civicrm_config();
-  if ($upgrader = _yoteup_civix_upgrader()) {
+function _nrm_civix_civicrm_uninstall() {
+  _nrm_civix_civicrm_config();
+  if ($upgrader = _nrm_civix_upgrader()) {
     $upgrader->onUninstall();
   }
 }
@@ -68,9 +68,9 @@ function _yoteup_civix_civicrm_uninstall() {
  *
  * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_enable
  */
-function _yoteup_civix_civicrm_enable() {
-  _yoteup_civix_civicrm_config();
-  if ($upgrader = _yoteup_civix_upgrader()) {
+function _nrm_civix_civicrm_enable() {
+  _nrm_civix_civicrm_config();
+  if ($upgrader = _nrm_civix_upgrader()) {
     if (is_callable(array($upgrader, 'onEnable'))) {
       $upgrader->onEnable();
     }
@@ -83,9 +83,9 @@ function _yoteup_civix_civicrm_enable() {
  * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_disable
  * @return mixed
  */
-function _yoteup_civix_civicrm_disable() {
-  _yoteup_civix_civicrm_config();
-  if ($upgrader = _yoteup_civix_upgrader()) {
+function _nrm_civix_civicrm_disable() {
+  _nrm_civix_civicrm_config();
+  if ($upgrader = _nrm_civix_upgrader()) {
     if (is_callable(array($upgrader, 'onDisable'))) {
       $upgrader->onDisable();
     }
@@ -103,20 +103,20 @@ function _yoteup_civix_civicrm_disable() {
  *
  * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_upgrade
  */
-function _yoteup_civix_civicrm_upgrade($op, CRM_Queue_Queue $queue = NULL) {
-  if ($upgrader = _yoteup_civix_upgrader()) {
+function _nrm_civix_civicrm_upgrade($op, CRM_Queue_Queue $queue = NULL) {
+  if ($upgrader = _nrm_civix_upgrader()) {
     return $upgrader->onUpgrade($op, $queue);
   }
 }
 
 /**
- * @return CRM_Yoteup_Upgrader
+ * @return CRM_NRM_Upgrader
  */
-function _yoteup_civix_upgrader() {
-  if (!file_exists(__DIR__.'/CRM/Yoteup/Upgrader.php')) {
+function _nrm_civix_upgrader() {
+  if (!file_exists(__DIR__.'/CRM/Nrm/Upgrader.php')) {
     return NULL;
   } else {
-    return CRM_Yoteup_Upgrader_Base::instance();
+    return CRM_NRM_Upgrader_Base::instance();
   }
 }
 
@@ -130,7 +130,7 @@ function _yoteup_civix_upgrader() {
  * @param $pattern string, glob pattern, eg "*.txt"
  * @return array(string)
  */
-function _yoteup_civix_find_files($dir, $pattern) {
+function _nrm_civix_find_files($dir, $pattern) {
   if (is_callable(array('CRM_Utils_File', 'findFiles'))) {
     return CRM_Utils_File::findFiles($dir, $pattern);
   }
@@ -139,7 +139,7 @@ function _yoteup_civix_find_files($dir, $pattern) {
   $result = array();
   while (!empty($todos)) {
     $subdir = array_shift($todos);
-    foreach (_yoteup_civix_glob("$subdir/$pattern") as $match) {
+    foreach (_nrm_civix_glob("$subdir/$pattern") as $match) {
       if (!is_dir($match)) {
         $result[] = $match;
       }
@@ -164,13 +164,13 @@ function _yoteup_civix_find_files($dir, $pattern) {
  *
  * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_managed
  */
-function _yoteup_civix_civicrm_managed(&$entities) {
-  $mgdFiles = _yoteup_civix_find_files(__DIR__, '*.mgd.php');
+function _nrm_civix_civicrm_managed(&$entities) {
+  $mgdFiles = _nrm_civix_find_files(__DIR__, '*.mgd.php');
   foreach ($mgdFiles as $file) {
     $es = include $file;
     foreach ($es as $e) {
       if (empty($e['module'])) {
-        $e['module'] = 'biz.jmaconsulting.yoteup';
+        $e['module'] = 'biz.jmaconsulting.nrm';
       }
       $entities[] = $e;
     }
@@ -186,12 +186,12 @@ function _yoteup_civix_civicrm_managed(&$entities) {
  *
  * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_caseTypes
  */
-function _yoteup_civix_civicrm_caseTypes(&$caseTypes) {
+function _nrm_civix_civicrm_caseTypes(&$caseTypes) {
   if (!is_dir(__DIR__ . '/xml/case')) {
     return;
   }
 
-  foreach (_yoteup_civix_glob(__DIR__ . '/xml/case/*.xml') as $file) {
+  foreach (_nrm_civix_glob(__DIR__ . '/xml/case/*.xml') as $file) {
     $name = preg_replace('/\.xml$/', '', basename($file));
     if ($name != CRM_Case_XMLProcessor::mungeCaseType($name)) {
       $errorMessage = sprintf("Case-type file name is malformed (%s vs %s)", $name, CRM_Case_XMLProcessor::mungeCaseType($name));
@@ -199,7 +199,7 @@ function _yoteup_civix_civicrm_caseTypes(&$caseTypes) {
       // throw new CRM_Core_Exception($errorMessage);
     }
     $caseTypes[$name] = array(
-      'module' => 'biz.jmaconsulting.yoteup',
+      'module' => 'biz.jmaconsulting.nrm',
       'name' => $name,
       'file' => $file,
     );
@@ -218,7 +218,7 @@ function _yoteup_civix_civicrm_caseTypes(&$caseTypes) {
  * @param string $pattern
  * @return array, possibly empty
  */
-function _yoteup_civix_glob($pattern) {
+function _nrm_civix_glob($pattern) {
   $result = glob($pattern);
   return is_array($result) ? $result : array();
 }
@@ -231,7 +231,7 @@ function _yoteup_civix_glob($pattern) {
  * $item - menu you need to insert (parent/child attributes will be filled for you)
  * $parentId - used internally to recurse in the menu structure
  */
-function _yoteup_civix_insert_navigation_menu(&$menu, $path, $item, $parentId = NULL) {
+function _nrm_civix_insert_navigation_menu(&$menu, $path, $item, $parentId = NULL) {
   static $navId;
 
   // If we are done going down the path, insert menu
@@ -255,7 +255,7 @@ function _yoteup_civix_insert_navigation_menu(&$menu, $path, $item, $parentId =
     foreach ($menu as $key => &$entry) {
       if ($entry['attributes']['name'] == $first) {
         if (!$entry['child']) $entry['child'] = array();
-        $found = _yoteup_civix_insert_navigation_menu($entry['child'], implode('/', $path), $item, $key);
+        $found = _nrm_civix_insert_navigation_menu($entry['child'], implode('/', $path), $item, $key);
       }
     }
     return $found;
@@ -267,7 +267,7 @@ function _yoteup_civix_insert_navigation_menu(&$menu, $path, $item, $parentId =
  *
  * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_alterSettingsFolders
  */
-function _yoteup_civix_civicrm_alterSettingsFolders(&$metaDataFolders = NULL) {
+function _nrm_civix_civicrm_alterSettingsFolders(&$metaDataFolders = NULL) {
   static $configured = FALSE;
   if ($configured) return;
   $configured = TRUE;
diff --git a/yoteup.php b/nrm.php
similarity index 70%
rename from yoteup.php
rename to nrm.php
index d5b975165b05eff4315903664cb0cbabfe26636b..4c2921d1fb8edb71b7d450e91e90bfe82694a94b 100644
--- a/yoteup.php
+++ b/nrm.php
@@ -1,14 +1,14 @@
 <?php
 
-require_once 'yoteup.civix.php';
+require_once 'nrm.civix.php';
 
 /**
  * Implementation of hook_civicrm_config
  *
  * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_config
  */
-function yoteup_civicrm_config(&$config) {
-  _yoteup_civix_civicrm_config($config);
+function nrm_civicrm_config(&$config) {
+  _nrm_civix_civicrm_config($config);
 }
 
 /**
@@ -18,8 +18,8 @@ function yoteup_civicrm_config(&$config) {
  *
  * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_xmlMenu
  */
-function yoteup_civicrm_xmlMenu(&$files) {
-  _yoteup_civix_civicrm_xmlMenu($files);
+function nrm_civicrm_xmlMenu(&$files) {
+  _nrm_civix_civicrm_xmlMenu($files);
 }
 
 /**
@@ -27,8 +27,8 @@ function yoteup_civicrm_xmlMenu(&$files) {
  *
  * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_install
  */
-function yoteup_civicrm_install() {
-  _yoteup_civix_civicrm_install();
+function nrm_civicrm_install() {
+  _nrm_civix_civicrm_install();
 }
 
 /**
@@ -36,8 +36,8 @@ function yoteup_civicrm_install() {
  *
  * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_uninstall
  */
-function yoteup_civicrm_uninstall() {
-  _yoteup_civix_civicrm_uninstall();
+function nrm_civicrm_uninstall() {
+  _nrm_civix_civicrm_uninstall();
 }
 
 /**
@@ -45,8 +45,8 @@ function yoteup_civicrm_uninstall() {
  *
  * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_enable
  */
-function yoteup_civicrm_enable() {
-  _yoteup_civix_civicrm_enable();
+function nrm_civicrm_enable() {
+  _nrm_civix_civicrm_enable();
 }
 
 /**
@@ -54,8 +54,8 @@ function yoteup_civicrm_enable() {
  *
  * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_disable
  */
-function yoteup_civicrm_disable() {
-  _yoteup_civix_civicrm_disable();
+function nrm_civicrm_disable() {
+  _nrm_civix_civicrm_disable();
 }
 
 /**
@@ -69,8 +69,8 @@ function yoteup_civicrm_disable() {
  *
  * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_upgrade
  */
-function yoteup_civicrm_upgrade($op, CRM_Queue_Queue $queue = NULL) {
-  return _yoteup_civix_civicrm_upgrade($op, $queue);
+function nrm_civicrm_upgrade($op, CRM_Queue_Queue $queue = NULL) {
+  return _nrm_civix_civicrm_upgrade($op, $queue);
 }
 
 /**
@@ -81,8 +81,8 @@ function yoteup_civicrm_upgrade($op, CRM_Queue_Queue $queue = NULL) {
  *
  * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_managed
  */
-function yoteup_civicrm_managed(&$entities) {
-  _yoteup_civix_civicrm_managed($entities);
+function nrm_civicrm_managed(&$entities) {
+  _nrm_civix_civicrm_managed($entities);
 }
 
 /**
@@ -94,8 +94,8 @@ function yoteup_civicrm_managed(&$entities) {
  *
  * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_caseTypes
  */
-function yoteup_civicrm_caseTypes(&$caseTypes) {
-  _yoteup_civix_civicrm_caseTypes($caseTypes);
+function nrm_civicrm_caseTypes(&$caseTypes) {
+  _nrm_civix_civicrm_caseTypes($caseTypes);
 }
 
 /**
@@ -103,11 +103,11 @@ function yoteup_civicrm_caseTypes(&$caseTypes) {
  *
  * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_alterSettingsFolders
  */
-function yoteup_civicrm_alterSettingsFolders(&$metaDataFolders = NULL) {
-  _yoteup_civix_civicrm_alterSettingsFolders($metaDataFolders);
+function nrm_civicrm_alterSettingsFolders(&$metaDataFolders = NULL) {
+  _nrm_civix_civicrm_alterSettingsFolders($metaDataFolders);
 }
 
-function yoteup_civicrm_alterMailParams(&$params, $context) { 
+function nrm_civicrm_alterMailParams(&$params, $context) { 
   if (CRM_Utils_Array::value('groupName', $params) == 'Report Email Sender') {
     $email = CRM_Utils_Request::retrieve('email_to_send', 'String', CRM_Core_DAO::$_nullObject);
     if ($email) {
diff --git a/CRM/Yoteup/BAO/Yoteup.php b/CRM/Nrm/BAO/Nrm.php
similarity index 97%
rename from CRM/Yoteup/BAO/Yoteup.php
rename to CRM/Nrm/BAO/Nrm.php
index 0af2af1fe60160fa08e8faeda441913bfdcdeb98..6b7f9d5c738e422ebb4b915780bb3de74dcde6aa 100644
--- a/CRM/Yoteup/BAO/Yoteup.php
+++ b/CRM/Nrm/BAO/Nrm.php
@@ -1,6 +1,7 @@
+
 <?php
 /**
  * Yote Up extension integrates CiviCRM's reports
  * 
  * Copyright (C) 2015 JMA Consulting
  *
@@ -17,7 +18,7 @@
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  * 
- * Support: https://github.com/JMAConsulting/biz.jmaconsulting.yoteup/issues
+ * Support: https://github.com/JMAConsulting/biz.jmaconsulting.nrm/issues
  * 
  * Contact: info@jmaconsulting.biz
  *          JMA Consulting
@@ -26,7 +27,7 @@
  *          Canada   M5T 2C7
  */
 
-class CRM_Yoteup_BAO_Yoteup extends CRM_Core_DAO {
+class CRM_Nrm_BAO_Nrm extends CRM_Core_DAO {
 
   /*
    * function to build select clause for reports
@@ -1,6 +1,7 @@
 <?php
 /**
- * Yote Up extension integrates CiviCRM's reports
+ * NRM extension integrates CiviCRM's reports
  * 
  * Copyright (C) 2015 JMA Consulting
diff --git a/yoteup_constants.php b/nrm_constants.php
similarity index 100%
rename from yoteup_constants.php
rename to nrm_constants.php
diff --git a/templates/CRM/Yoteup/Form/Report/IndividualCounselor.tpl b/templates/CRM/Nrm/Form/Report/IndividualCounselor.tpl
similarity index 100%
rename from templates/CRM/Yoteup/Form/Report/IndividualCounselor.tpl
rename to templates/CRM/Nrm/Form/Report/IndividualCounselor.tpl
diff --git a/templates/CRM/Yoteup/Form/Report/ManagementSummary.tpl b/templates/CRM/Nrm/Form/Report/ManagementSummary.tpl
similarity index 100%
rename from templates/CRM/Yoteup/Form/Report/ManagementSummary.tpl
rename to templates/CRM/Nrm/Form/Report/ManagementSummary.tpl
diff --git a/templates/CRM/Yoteup/Form/Report/SurveyDaily.tpl b/templates/CRM/Nrm/Form/Report/SurveyDaily.tpl
similarity index 100%
rename from templates/CRM/Yoteup/Form/Report/SurveyDaily.tpl
rename to templates/CRM/Nrm/Form/Report/SurveyDaily.tpl